/*
 * iphone-specific implementation of the PokktNativeExtension extension.
 * Add any platform-specific functionality here.
 */
/*
 * NOTE: This file was originally written by the extension builder, but will not
 * be overwritten (unless --force is specified) and is intended to be modified.
 */
#include "PokktNativeExtension_internal.h"
#import <Foundation/Foundation.h>
#import "PokktManager.h"
#import "VideoResponse.h"
#include <string>
#include "IwDebug.h"
#include "s3eDevice.h"
#include "s3eEdk.h"
#include "s3eEdk_iphone.h"

const std::string VideoClosedEvent = "videoClosed";
const std::string VideoDisplayedEvent = "videoDisplayed";
const std::string VideoSkippedEvent = "videoSkipped";
const std::string VideoCompletedEvent = "videoCompleted";
const std::string VideoGratifiedEvent = "videoGratified";
const std::string ShowIntent = "showIntent";
const std::string DownloadCompletedEvent = "downloadCompleted";
const std::string DownloadFailedEvent = "downloadFailed";


// use this to notify the cocos2dx
static void NotifyMarmalade(const char* operation, const char*  param)
{
    //PokktCocosManager::getInstance()->handleNativeMessage(operation, param);
    
    CallbackData data;
    data.operation = operation;
    data.params = param;
    IwTrace(POKKTNATIVEEXTENSION, ("NotifyCPP called success. operationString: %s and paramString: %s", data.operation, data.params));
    
    s3eEdkCallbacksEnqueue(S3E_EXT_POKKTNATIVEEXTENSION_HASH, OPERATION_EVENT, &data, sizeof(data));
}

PokktConfig *pokktConfig;

@interface IOSExtension:NSObject<PokktDelegate>
@end

@implementation IOSExtension

#pragma mark - Pokkt Delegates

- (void)didFinishedVideoDownload:(BOOL)isFinished
{
    IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : %s", "DownloadCompletedEvent"));
    float vc = [PokktManager getVideoVc];
    NotifyMarmalade(DownloadCompletedEvent.c_str(), [[NSString stringWithFormat:@"%@", [[NSNumber numberWithFloat:vc] stringValue]] UTF8String]);
}

- (void)didFailedVideoDownload:(NSString *)error
{
    IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : %s", "DownloadFailedEvent"));
    NotifyMarmalade(DownloadFailedEvent.c_str(), [[NSString stringWithFormat:@"%@", error] UTF8String]);
}

- (void)onVideoCompleated:(BOOL)isCompleated
{
    IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : %s", "VideoCompletedEvent"));
    NotifyMarmalade(VideoCompletedEvent.c_str(), "Video is completed");
}

- (void)onVideoDisplayed
{
   IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : %s", "VideoDisplayedEvent"));
   NotifyMarmalade(VideoDisplayedEvent.c_str(), "Video is displayed");
}

- (void)onVideoClosed
{
    IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : %s", "VideoClosedEvent"));
    NotifyMarmalade(VideoClosedEvent.c_str(), "Video is closed");
}

- (void)onVideoGratified:(VideoResponse *)videoResponse
{
    IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : %s", "VideoGratifiedEvent"));
    NotifyMarmalade(VideoGratifiedEvent.c_str(), [[NSString stringWithFormat:@"%@", videoResponse.coins] UTF8String]);
}

- (void)onVideoSkiped
{
    IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : %s", "VideoSkippedEvent"));
    NotifyMarmalade(VideoSkippedEvent.c_str(), "Video is skipped");
}

s3eResult PokktNativeExtensionInit_platform()
{
    // Add any platform-specific initialisation code here
    return S3E_RESULT_SUCCESS;
}

void PokktNativeExtensionTerminate_platform()
{

}

void notifyExtensionOnNative_platform(const char* operation, const char* param)
{
    IwTrace("POKKTNATIVEEXTENSION", ("NotifyCPP called success. operationString : operation: %s, params: %s", operation, param));

    NSString *paramNSStr = [NSString stringWithUTF8String:(param)];
    
    // common methods
    
    if (std::strcmp(operation, "setParams") == 0)
    {
        NSArray *paramArray = [paramNSStr componentsSeparatedByString:@","];
        pokktConfig  = [[PokktConfig alloc]init];
        
        if (paramArray != nil && paramArray.count >= 3)
        {
            pokktConfig.securityKey = [paramArray objectAtIndex:0];
            pokktConfig.applicationId = [paramArray objectAtIndex:1];
            pokktConfig.autoCacheVideo = [[paramArray objectAtIndex:3] boolValue];
            
            [PokktManager initPokkt:pokktConfig];
            
            IOSExtension *ext = [[IOSExtension alloc] init];
            [PokktManager setPokktDelegate:ext];
            
        }
        // set the view controller
        UIViewController *viewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
        [PokktManager setPresentView:viewController];
    }
    
    else if (std::strcmp(operation, "setDebug") == 0)
    {
        BOOL debug = (std::strcmp(param, "true") == 0);
        [PokktManager setDebug:debug];
    }
    
    else if (std::strcmp(operation, "showLog") == 0)
    {
        NSLog(@"[POKKTLOG] %@",paramNSStr);
    }
    
    else if (std::strcmp(operation, "showToast") == 0)
    {
        NSLog(@"[POKKTLOG] %@",@"iOS plugin does not support showToast!!");
    }
    
    else if (std::strcmp(operation, "setThirdPartyUserId") == 0)
    {
        pokktConfig.thirdPartyUserId = paramNSStr;
    }
    
    // session methods
    
    else if(std::strcmp(operation, "startSession") == 0)
    {
        [PokktManager startSession:pokktConfig];
    }
    
    else if(std::strcmp(operation, "endSession") == 0)
    {
        [PokktManager endSession];
    }
    
    // OfferWall methods
    // all offerwall methods should log as error in default case
    
    // Video Methods
    
    else if (std::strcmp(operation, "getVideo") == 0)
    {
        pokktConfig.screenName = paramNSStr;
        pokktConfig.incentivised = YES;
        [PokktManager playVideoCampaign:pokktConfig];
    }
    
    else if (std::strcmp(operation, "getVideoNonIncent") == 0)
    {
        pokktConfig.screenName = paramNSStr;
        pokktConfig.incentivised = NO;
        [PokktManager playVideoCampaign:pokktConfig];
    }
    
    else if (std::strcmp(operation, "cacheVideoCampaign") == 0)
    {
        [PokktManager cacheVideoCampaign:pokktConfig];
    }
    
    else if (std::strcmp(operation, "setSkipEnabled") == 0)
    {
        [pokktConfig setSkipEnabled:(std::strcmp(param, "true") == 0)];
    }
    
    else if (std::strcmp(operation, "setDefaultSkipTime") == 0)
    {
        [pokktConfig setDefaultSkipTime:[paramNSStr intValue]];
    }
    
    else if (std::strcmp(operation, "setCustomSkipMessage") == 0)
    {
        [pokktConfig setCustomSkipMessage:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setBackButtonDisabled") == 0)
    {
        NSLog(@"[POKKTLOG] %@",@"iOS plugin does not support setBackButtonDisabled!!");
    }
    
    // optional methods
    
    else if (std::strcmp(operation, "setName") == 0)
    {
        [pokktConfig setName:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setAge") == 0)
    {
        [pokktConfig setAge:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setSex") == 0)
    {
        [pokktConfig setSex:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setMobileNo") == 0)
    {
        [pokktConfig setMobileNo:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setEmailAddress") == 0)
    {
        [pokktConfig setEmailAddress:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setLocation") == 0)
    {
        [pokktConfig setLocation:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setBirthday") == 0)
    {
        [pokktConfig setBirthday:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setMaritalStatus") == 0)
    {
        [pokktConfig setMaritalStatus:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setFacebookId") == 0)
    {
        [pokktConfig setFacebookId:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setTwitterHandle") == 0)
    {
        [pokktConfig setTwitterHandle:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setEducation") == 0)
    {
        [pokktConfig setEducation:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setNationality") == 0)
    {
        [pokktConfig setNationality:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setEmployment") == 0)
    {
        [pokktConfig setEmployment:paramNSStr];
    }
    
    else if (std::strcmp(operation, "setMaturityRating") == 0)
    {
        [pokktConfig setMaturityRating:paramNSStr];
    }
    
    else
    {
        NSLog(@"[POKKTLOG] %@",[NSString stringWithFormat:@"iOS plugin does not support %s operation",operation]);
    }
}

bool isVideoAvailableOnNative_platform()
{
    return [PokktManager isVideoAvailable];
}

double getVideoVcOnNative_platform()
{
    double vc = [PokktManager getVideoVc];
    return vc;
}

const char * getPokktSDKVersionOnNative_platform()
{
    const char* version = [[NSString stringWithFormat:@"%@", [PokktManager getSDKVersion]] UTF8String];
    return version;
}

@end